utilp
#####
|PyPI-Status| |PyPI-Versions| |Build-Status| |Codecov| |LICENCE|

Shay Palachy's personal common Python 3 utility functions and classes.

.. code-block:: python

  >>> from utilp.classes import Bunch
  >>> bunch = Bunch()
  >>> bunch.a = 5
  >>> print(bunch.a)
  5


Installation
============

Install ``utilp`` with:

.. code-block:: bash

  pip install utilp


Credits
=======
Created by Shay Palachy  (shay.palachy@gmail.com).

.. |PyPI-Status| image:: https://img.shields.io/pypi/v/utilp.svg
  :target: https://pypi.python.org/pypi/utilp

.. |PyPI-Versions| image:: https://img.shields.io/pypi/pyversions/utilp.svg
   :target: https://pypi.python.org/pypi/utilp

.. |Build-Status| image:: https://github.com/shaypal5/utilp/actions/workflows/test.yml/badge.svg
  :target: https://github.com/shaypal5/utilp/actions/workflows/test.yml

.. |LICENCE| image:: https://img.shields.io/pypi/l/utilp.svg
  :target: https://pypi.python.org/pypi/utilp

.. |Codecov| image:: https://codecov.io/github/shaypal5/utilp/coverage.svg?branch=master
   :target: https://codecov.io/github/shaypal5/utilp?branch=master
